@@ -1,3 +1,5 @@
+"""dynaPreprocessing Class"""
+
 #!/usr/bin/env python
 
 import itertools
@@ -45,6 +47,40 @@ delete_old_log_files(directory = logs_folder ,delete_flag = DELETE_FLAG, logger
 logger.info(Test_comment)
 
 class dynaPreprocessing:
+    """Automated feature preprocessing including imputation, winsorization, encoding, and scaling in ensemble algorithms, to generate permutation input datasets for further pipeline components.
+    
+    Parameters
+    ----------
+    custom_parameters: dictionary, default = None
+        Custom parameters settings input.
+        
+        NOTE: default_parameters 
+            = {
+            "scaler" : ["None", "standard", "minmax", "maxabs", "robust"],
+            "encode_band" : [10],
+            "low_encode" : ["onehot","label"], 
+            "high_encode" : ["frequency", "mean"],
+            "winsorizer" : [(0.01,0.01),(0.05,0.05)],
+            "sparsity" : [0.40],
+            "cols" : [30]
+            }
+
+    label_col: str, default = None
+        Name of label column.
+    model_type: str, default = "reg"
+        "reg" for regression problem or "cls" for classification problem - Default: "reg".
+    export_output_files: bool, default = False
+        Export qualified permutated datasets to ./df_folder.
+    
+    Example
+    -------
+
+    .. [Example] https://dynamic-pipeline.readthedocs.io/en/latest/demos.html#feature-preprocessing-for-a-regression-problem-using-autopp
+    
+    References
+    ----------
+    None
+    """
     def __init__(self, custom_parameters = None, label_col = None, model_type = "reg",export_output_files = False):
 
         default_parameters = {
@@ -66,6 +102,25 @@ class dynaPreprocessing:
         self.label_col = label_col
 
     def fit(self, input_data = None):
+        """Fits and transforms a pandas dataframe to non-missing values, outlier excluded, categories encoded and scaled datasets by all algorithms permutation.
+        
+        Parameters
+        ----------
+        input_data : pandas dataframe, shape = [n_samples, n_features]
+            
+            NOTE: 
+            The input_data should be the datasets after basic data cleaning & well feature deduction, the more features involve will result in more columns permutation outputs. 
+        
+        Returns
+        -------
+        DICT_PREP_DF : dictionary
+            Each key is the # of output preprocessed dataset, each value stores the dataset
+        DICT_PREP_INFO : dictionary
+            Dictionary for reference. Each key is the # of the output preprocessed dataset, each value stores the column names of the dataset
+        
+        NOTE - Log records will generate and save to ./logs folder automatedly.
+        """
+                        
         if (self.export_output_files):
             df_folder = os.path.join(os.getcwd(),'dfs')
             if not os.path.exists(df_folder):
@@ -78,7 +133,7 @@ class dynaPreprocessing:
             pp.split_category_cols()
             initial_num_cols = pp.num_df.columns
             pp.impute_tool()
-            pp.winzorize_tool(lower_ban = self.parameters.get("winsorizer")[i][0],upper_ban = self.parameters.get("winsorizer")[i][1])
+            pp.winsorize_tool(lower_ban = self.parameters.get("winsorizer")[i][0],upper_ban = self.parameters.get("winsorizer")[i][1])
             winsorized_df_cols_list = list(pp.num_df.columns)
             encoded_cols_list = {}
             for col in pp.cat_df.columns:
